@@ -5,6 +5,8 @@ from .utils import AddMaterialFromDir
 from .utils import AddMaterialFromFile
 from .utils import AvailableMaterials
 from .utils import material_dict
+from .utils import isotope_to_zaid
+from .utils import zaid_to_isotope
 
 from .material import Material
 from .mutlimaterial import MultiMaterial
