@@ -9,8 +9,8 @@ try:
     import openmc
 except BaseException:
     warnings.warn(
-        "OpenMC python package not found, .openmc_material, .serpent_material, .mcnp_material, .fispact_material methods not avaiable"
-    )
+        "OpenMC python package not found, .openmc_material, .serpent_material, \
+            .mcnp_material, .fispact_material methods not avaiable")
 
 from CoolProp.CoolProp import PropsSI
 import neutronics_material_maker as nmm
@@ -59,9 +59,12 @@ class MultiMaterial:
             to 1/void fraction
         zaid_suffix (str): The nuclear library to apply to the zaid, for example
             ".31c", this is used in MCNP and Serpent material cards.
-        material_id (int): The id number or mat number used in the MCNP material card
-        volume_in_cm3 (float): The volume of the material in cm3, used when creating
-            fispact material cards
+        material_id (int): The id number or mat number used in the MCNP material
+            card
+        decimal_places (int): The number of decimal places to use in MCNP and
+            Seprent material cards when they are printed out (default of 8).
+        volume_in_cm3 (float): The volume of the material in cm3, used when
+            creating fispact material cards
 
     Returns:
         Material: a neutronics_material_maker.Material instance
@@ -77,6 +80,7 @@ class MultiMaterial:
         packing_fraction=1.0,
         zaid_suffix=None,
         material_id=None,
+        decimal_places=8,
         volume_in_cm3=None,
     ):
         self.material_tag = material_tag
@@ -86,6 +90,7 @@ class MultiMaterial:
         self.packing_fraction = packing_fraction
         self.zaid_suffix = zaid_suffix
         self.material_id = material_id
+        self.decimal_places = decimal_places
         self.volume_in_cm3 = volume_in_cm3
 
         # derived values
@@ -100,9 +105,11 @@ class MultiMaterial:
 
         if sum(self.fracs) != 1.0:
             warnings.warn(
-                "warning sum of MutliMaterials do not sum to 1." +
-                str(self.fracs) + " = " + str(sum(self.fracs)),
-                UserWarning
+                "warning sum of MutliMaterials do not sum to 1."
+                + str(self.fracs)
+                + " = "
+                + str(sum(self.fracs)),
+                UserWarning,
             )
 
     @property
@@ -234,6 +241,7 @@ class MultiMaterial:
                     "reference": material.reference,
                     "zaid_suffix": material.zaid_suffix,
                     "material_id": material.material_id,
+                    "decimal_places": material.decimal_places,
                     "volume_in_cm3": material.volume_in_cm3,
                 })
 
@@ -245,6 +253,7 @@ class MultiMaterial:
             "packing_fraction": self.packing_fraction,
             "zaid_suffix": self.zaid_suffix,
             "material_id": self.material_id,
+            "decimal_places": self.decimal_places,
             "volume_in_cm3": self.volume_in_cm3,
         }
 
