@@ -510,6 +510,28 @@ class test_object_properties(unittest.TestCase):
             li_fraction / (pb_fraction + li_fraction))
 
     def test_incorrect_settings(self):
+
+        def enrichment_too_high():
+            """checks a ValueError is raised when enrichment is over 100"""
+
+            nmm.Material("Li4SiO4", enrichment=200)
+
+        self.assertRaises(ValueError, enrichment_too_high)
+
+        def enrichment_too_low():
+            """checks a ValueError is raised when enrichment is under 0"""
+
+            nmm.Material("Li4SiO4", enrichment=-10)
+
+        self.assertRaises(ValueError, enrichment_too_low)
+
+        def incorrect_pressure_in_Pa():
+            """checks a ValueError is raised when pressure_in_Pa is below 0"""
+
+            nmm.Material("H2O", temperature_in_C=10, pressure_in_Pa=-1e6)
+
+        self.assertRaises(ValueError, incorrect_pressure_in_Pa)
+
         def incorrect_temperature_in_K():
             """checks a ValueError is raised when temperature_in_K is below 0"""
 
@@ -524,6 +546,21 @@ class test_object_properties(unittest.TestCase):
 
         self.assertRaises(ValueError, incorrect_temperature_in_C)
 
+        def incorrect_elements_chemical_equation_usage():
+            """checks a ValueError is raised when the both chemical_equation and elements are used"""
+
+            nmm.Material(
+                material_name='my_mat',
+                enrichment=50.0,
+                chemical_equation="Li4SiO4",
+                elements={'C': 0.3333, 'O': 0.666},
+                enrichment_type="ao",
+            )
+
+        self.assertRaises(
+            ValueError,
+            incorrect_elements_chemical_equation_usage)
+
         def incorrect_enrichment_target():
             """checks a ValueError is raised when the enrichment target is not a natural isotope"""
 
@@ -536,6 +573,19 @@ class test_object_properties(unittest.TestCase):
 
         self.assertRaises(ValueError, incorrect_enrichment_target)
 
+        # TODO get this working
+        # def no_enrichment_target():
+        #     """checks a ValueError is raised when the enrichment target is set to none"""
+
+        #     nmm.Material(
+        #         material_name="my_mat",
+        #         chemical_equation="Li4SiO",
+        #         enrichment=50.0,
+        #         enrichment_target=None,
+        #         enrichment_type=None,
+        #     )
+        # self.assertRaises(ValueError, no_enrichment_target)
+
         def incorrect_reference_type():
             """checks a ValueError is raised when the reference is an int"""
 
